package com.yj.service;

import com.yj.bean.Book;
import com.yj.bean.Page;
import com.yj.bean.User;

import java.util.List;

/**
 * 用户服务接口，定义与用户相关的操作
 * @author yj
 * @create 2020-08-21 15:29
 */
public interface UserService {

    /**
     * 注册用户
     * @param user 要注册的用户对象
     */
    public void registUser(User user);

    /**
     * 登录方法
     * @param user 包含用户名和密码的用户对象
     * @return 返回登录成功的用户对象，如果失败则返回null
     */
    public User login(User user);

    /**
     * 检查用户名是否可用
     * @param username 待检查的用户名
     * @return 返回true表示用户名已存在，返回false表示用户名可用
     */
    public boolean existsUsername(String username);

    /**
     * 添加新用户
     * @param user 要添加的用户对象
     */
    public void addUser(User user);

    /**
     * 根据用户ID删除用户
     * @param id 要删除的用户ID
     */
    public void deleteUserById(int id);

    /**
     * 更新用户信息
     * @param user 包含更新信息的用户对象
     */
    public void updateUser(User user);

    /**
     * 根据用户ID查询用户
     * @param id 用户ID
     * @return 返回对应的用户对象，如果不存在则返回null
     */
    public User queryUserById(Integer id);

    /**
     * 查询所有用户
     * @return 返回包含所有用户的列表
     */
    public List<User> queryUsers();

    /**
     * 分页查询用户
     * @param pageNo 当前页码
     * @param pageSize 每页记录数
     * @return 返回分页对象，包含当前页的用户列表和其他分页信息
     */
    public Page<User> page(int pageNo, int pageSize);
}
